@@ -1,6 +1,6 @@
 import pytest
 
-from covid19_outbreak_simulator.model import Params, Model, get_default_params
+from covid19_outbreak_simulator.model import Params, Model
 from covid19_outbreak_simulator.simulator import Simulator, Individual
 from argparse import Namespace
 
@@ -10,14 +10,9 @@ def params():
     return Params()
 
 
-@pytest.fixture
-def default_params():
-    return get_default_params()
-
-
 @pytest.fixture
 def default_model():
-    return Model(get_default_params())
+    return Model(Params())
 
 
 @pytest.fixture
@@ -28,21 +23,21 @@ def logger():
 
 
 @pytest.fixture
-def simulator(default_params, logger):
+def simulator(params, logger):
     simu_args = Namespace()
     simu_args.popsize = 64
     simu_args.repeat = 1
     simu_args.keep_symptomatic = True
     simu_args.pre_quarantine = None
 
-    return Simulator(params=default_params, logger=logger, simu_args=simu_args)
+    return Simulator(params=params, logger=logger, simu_args=simu_args)
 
 
 @pytest.fixture
 def individual(default_model, logger):
-    return Individual(0, default_model, logger)
+    return Individual(0, 'group', 0.8, default_model, logger)
 
 
 @pytest.fixture
 def individual_factory(default_model, logger):
-    return lambda id: Individual(id, default_model, logger)
\ No newline at end of file
+    return lambda id: Individual(id, 'group 2', 1.2, default_model, logger)
\ No newline at end of file
